@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,8 +15,9 @@ class GearySettings : public AbstractSettings
 {
 public:
     explicit GearySettings(const QString &filename);
-    ~GearySettings();
+    ~GearySettings() override;
     void importSettings();
+
 private:
     void readImapAccount();
     void readIdentity();
