@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,8 +8,8 @@
 
 #include "../searchduplicate/searchandmergecontactduplicatecontactdialog.h"
 
-#include <QTest>
 #include <QStandardPaths>
+#include <QTest>
 
 #include <QStackedWidget>
 using namespace KABMergeContacts;
@@ -35,12 +35,9 @@ void SearchAndMergeContactDuplicateContactDialogTest::shouldHaveDefaultValueOnCr
     for (int i = 0; i < stackedWidget->count(); ++i) {
         QWidget *w = stackedWidget->widget(i);
         const QString objName = w->objectName();
-        const bool hasGoodNamePage = (objName == QLatin1String("mergecontact")
-                                      || objName == QLatin1String("nocontactselected")
-                                      || objName == QLatin1String("nocontactduplicatesfound")
-                                      || objName == QLatin1String("noenoughcontactselected")
-                                      || objName == QLatin1String("mergecontactresult")
-                                      || objName == QLatin1String("selectioninformation"));
+        const bool hasGoodNamePage = (objName == QLatin1String("mergecontact") || objName == QLatin1String("nocontactselected")
+                                      || objName == QLatin1String("nocontactduplicatesfound") || objName == QLatin1String("noenoughcontactselected")
+                                      || objName == QLatin1String("mergecontactresult") || objName == QLatin1String("selectioninformation"));
         QVERIFY(hasGoodNamePage);
     }
 }
