@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,16 +7,17 @@
 #ifndef SEARCHPOTENTIALDUPLICATECONTACTJOB_H
 #define SEARCHPOTENTIALDUPLICATECONTACTJOB_H
 
-#include <QObject>
 #include <AkonadiCore/Item>
+#include <QObject>
 
-namespace KABMergeContacts {
+namespace KABMergeContacts
+{
 class SearchPotentialDuplicateContactJob : public QObject
 {
     Q_OBJECT
 public:
     explicit SearchPotentialDuplicateContactJob(const Akonadi::Item::List &list, QObject *parent = nullptr);
-    ~SearchPotentialDuplicateContactJob();
+    ~SearchPotentialDuplicateContactJob() override;
 
     void start();
 
@@ -29,7 +30,7 @@ private:
     Akonadi::Item::List checkList(const Akonadi::Item::List &lstItem);
     bool isDuplicate(const Akonadi::Item &itemA, const Akonadi::Item &itemB);
     Akonadi::Item::List mListItem;
-    QVector<Akonadi::Item::List > mListDuplicate;
+    QVector<Akonadi::Item::List> mListDuplicate;
 };
 }
 
