@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef MERGECONTACTWIDGETLIST_H
 #define MERGECONTACTWIDGETLIST_H
 
-#include <QListWidget>
 #include <AkonadiCore/Item>
 #include <KContacts/Addressee>
+#include <QListWidget>
 
-namespace KABMergeContacts {
+namespace KABMergeContacts
+{
 class MergeContactWidgetListItem : public QListWidgetItem
 {
 public:
@@ -27,11 +28,12 @@ class MergeContactWidgetList : public QListWidget
     Q_OBJECT
 public:
     explicit MergeContactWidgetList(QWidget *parent = nullptr);
-    ~MergeContactWidgetList();
+    ~MergeContactWidgetList() override;
 
     void fillListContact(const Akonadi::Item::List &items);
     Akonadi::Item::List listSelectedContacts() const;
     Akonadi::Item currentAkonadiItem() const;
+
 private:
     QString itemName(const KContacts::Addressee &address) const;
 };
