@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,18 +7,20 @@
 #ifndef RESULTDUPLICATETREEWIDGET_H
 #define RESULTDUPLICATETREEWIDGET_H
 
-#include <QTreeWidget>
-#include <AkonadiCore/Item>
 #include "kaddressbookmergelib_export.h"
-namespace KContacts {
+#include <AkonadiCore/Item>
+#include <QTreeWidget>
+namespace KContacts
+{
 class Addressee;
 }
-namespace KABMergeContacts {
+namespace KABMergeContacts
+{
 class KADDRESSBOOKMERGELIB_EXPORT ResultDuplicateTreeWidgetItem : public QTreeWidgetItem
 {
 public:
     explicit ResultDuplicateTreeWidgetItem(QTreeWidget *parent = nullptr);
-    ~ResultDuplicateTreeWidgetItem();
+    ~ResultDuplicateTreeWidgetItem() override;
 
     Q_REQUIRED_RESULT Akonadi::Item item() const;
     void setItem(const Akonadi::Item &item);
@@ -34,13 +36,14 @@ class KADDRESSBOOKMERGELIB_EXPORT ResultDuplicateTreeWidget : public QTreeWidget
     Q_OBJECT
 public:
     explicit ResultDuplicateTreeWidget(QWidget *parent = nullptr);
-    ~ResultDuplicateTreeWidget();
+    ~ResultDuplicateTreeWidget() override;
     void setContacts(const QVector<Akonadi::Item::List> &lstItem);
 
     Q_REQUIRED_RESULT QVector<Akonadi::Item::List> selectedContactsToMerge() const;
 
 Q_SIGNALS:
     void showContactPreview(const Akonadi::Item &item);
+
 private:
     void slotItemActivated(QTreeWidgetItem *item, int column);
     void slotItemChanged(QTreeWidgetItem *item, int column);
