@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,13 +7,14 @@
 #ifndef SEARCHANDMERGECONTACTDUPLICATECONTACTDIALOG_H
 #define SEARCHANDMERGECONTACTDUPLICATECONTACTDIALOG_H
 
-#include <QDialog>
 #include <AkonadiCore/Item>
+#include <QDialog>
 
-#include "searchduplicateresultwidget.h"
 #include "kaddressbookmergelib_export.h"
+#include "searchduplicateresultwidget.h"
 class QStackedWidget;
-namespace KABMergeContacts {
+namespace KABMergeContacts
+{
 class SearchDuplicateResultWidget;
 class MergeContactShowResultTabWidget;
 class MergeContactSelectInformationTabWidget;
@@ -24,7 +25,7 @@ class KADDRESSBOOKMERGELIB_EXPORT SearchAndMergeContactDuplicateContactDialog :
     Q_OBJECT
 public:
     explicit SearchAndMergeContactDuplicateContactDialog(QWidget *parent = nullptr);
-    ~SearchAndMergeContactDuplicateContactDialog();
+    ~SearchAndMergeContactDuplicateContactDialog() override;
 
     void searchPotentialDuplicateContacts(const Akonadi::Item::List &list);
 
