@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 
 #include <QLabel>
 
-namespace KABMergeContacts {
+namespace KABMergeContacts
+{
 class MergeContactErrorLabel : public QLabel
 {
     Q_OBJECT
@@ -17,10 +18,10 @@ public:
     enum ErrorType {
         NotEnoughContactsSelected = 0,
         NoContactDuplicatesFound,
-        NoContactSelected
+        NoContactSelected,
     };
     explicit MergeContactErrorLabel(MergeContactErrorLabel::ErrorType type, QWidget *parent = nullptr);
-    ~MergeContactErrorLabel();
+    ~MergeContactErrorLabel() override;
 };
 }
 
