@@ -1,26 +1,26 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "mergecontactselectinformationscrollarea.h"
-#include "mergecontactselectinformationwidget.h"
 #include "job/mergecontactsjob.h"
-#include "widgets/mergecontactinfowidget.h"
 #include "kaddressbookmergelibprivate_debug.h"
+#include "mergecontactselectinformationwidget.h"
+#include "widgets/mergecontactinfowidget.h"
 #include <KLocalizedString>
-#include <QVBoxLayout>
+#include <KMessageBox>
+#include <QPushButton>
 #include <QScrollArea>
 #include <QStackedWidget>
-#include <QPushButton>
-#include <KMessageBox>
+#include <QVBoxLayout>
 using namespace KABMergeContacts;
 
 MergeContactSelectInformationScrollArea::MergeContactSelectInformationScrollArea(QWidget *parent)
     : QWidget(parent)
 {
-    auto *vbox = new QVBoxLayout(this);
+    auto vbox = new QVBoxLayout(this);
     vbox->setContentsMargins({});
     mStackWidget = new QStackedWidget;
     mStackWidget->setObjectName(QStringLiteral("stackwidget"));
@@ -28,9 +28,9 @@ MergeContactSelectInformationScrollArea::MergeContactSelectInformationScrollArea
 
     QWidget *selectMergeWidget = new QWidget;
     selectMergeWidget->setObjectName(QStringLiteral("selectwidget"));
-    auto *layout = new QVBoxLayout;
+    auto layout = new QVBoxLayout;
     selectMergeWidget->setLayout(layout);
-    auto *area = new QScrollArea;
+    auto area = new QScrollArea;
     area->setWidgetResizable(true);
     area->setObjectName(QStringLiteral("scrollarea"));
     layout->addWidget(area);
@@ -38,7 +38,7 @@ MergeContactSelectInformationScrollArea::MergeContactSelectInformationScrollArea
     mSelectInformationWidget->setObjectName(QStringLiteral("selectinformationwidget"));
     area->setWidget(mSelectInformationWidget);
 
-    auto *hbox = new QHBoxLayout;
+    auto hbox = new QHBoxLayout;
     hbox->addStretch();
     QPushButton *mergeButton = new QPushButton(i18n("Merge"));
     mergeButton->setObjectName(QStringLiteral("merge"));
@@ -58,7 +58,9 @@ MergeContactSelectInformationScrollArea::~MergeContactSelectInformationScrollAre
 {
 }
 
-void MergeContactSelectInformationScrollArea::setContacts(MergeContacts::ConflictInformations conflictTypes, const Akonadi::Item::List &listItem, const Akonadi::Collection &col)
+void MergeContactSelectInformationScrollArea::setContacts(MergeContacts::ConflictInformations conflictTypes,
+                                                          const Akonadi::Item::List &listItem,
+                                                          const Akonadi::Collection &col)
 {
     mCollection = col;
     mListItem = listItem;
@@ -83,8 +85,10 @@ void MergeContactSelectInformationScrollArea::slotMergeContacts()
     }
     const bool result = mSelectInformationWidget->verifySelectedInfo();
     if (!result) {
-        if (KMessageBox::No == KMessageBox::warningYesNo(this, i18n("Some information was not selected. You can lose this information. Do you want to continue merging?"),
-                                                         i18n("Missing Selected Information"))) {
+        if (KMessageBox::No
+            == KMessageBox::warningYesNo(this,
+                                         i18n("Some information was not selected. You can lose this information. Do you want to continue merging?"),
+                                         i18n("Missing Selected Information"))) {
             return;
         }
     }
@@ -97,7 +101,7 @@ void MergeContactSelectInformationScrollArea::slotMergeContacts()
 void MergeContactSelectInformationScrollArea::mergeContact(const KContacts::Addressee &addr)
 {
     if (!addr.isEmpty()) {
-        auto *job = new KABMergeContacts::MergeContactsJob(this);
+        auto job = new KABMergeContacts::MergeContactsJob(this);
         job->setNewContact(addr);
         job->setDestination(mCollection);
         job->setListItem(mListItem);
