@@ -1,26 +1,28 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef SENDVCARDSJOB_H
 #define SENDVCARDSJOB_H
-#include <QObject>
 #include <AkonadiCore/Item>
 #include <KContacts/VCardConverter>
+#include <QObject>
 
 class QTemporaryDir;
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class AttachmentTemporaryFilesDirs;
 }
-namespace KABSendVCards {
+namespace KABSendVCards
+{
 class SendVcardsJob : public QObject
 {
     Q_OBJECT
 public:
     explicit SendVcardsJob(const Akonadi::Item::List &listItem, QObject *parent = nullptr);
-    ~SendVcardsJob();
+    ~SendVcardsJob() override;
 
     Q_REQUIRED_RESULT bool start();
 
