@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class MarkdownCreateLinkWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit MarkdownCreateLinkWidgetTest(QObject *parent = nullptr);
-    ~MarkdownCreateLinkWidgetTest() = default;
+    ~MarkdownCreateLinkWidgetTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldGenerateLink();
