@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class MarkdownPluginTest : public QObject
     Q_OBJECT
 public:
     explicit MarkdownPluginTest(QObject *parent = nullptr);
-    ~MarkdownPluginTest() = default;
+    ~MarkdownPluginTest() override = default;
 private Q_SLOTS:
     void shouldCreateInterface();
 };
