@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class MarkdownUtilTest : public QObject
     Q_OBJECT
 public:
     explicit MarkdownUtilTest(QObject *parent = nullptr);
-    ~MarkdownUtilTest() = default;
+    ~MarkdownUtilTest() override = default;
 private Q_SLOTS:
     void shouldConvert();
     void shouldConvert_data();
