@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,14 +7,14 @@
 #ifndef MARKDOWNCONVERTER_H
 #define MARKDOWNCONVERTER_H
 
-#include <QObject>
 #include "libkmailmarkdown_export.h"
+#include <QObject>
 class LIBKMAILMARKDOWN_EXPORT MarkdownConverter : public QObject
 {
     Q_OBJECT
 public:
     explicit MarkdownConverter(QObject *parent = nullptr);
-    ~MarkdownConverter();
+    ~MarkdownConverter() override;
     Q_REQUIRED_RESULT QString convertTextToMarkdown(const QString &str);
 
     Q_REQUIRED_RESULT bool enableEmbeddedLabel() const;
