@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef MARKDOWNPREVIEWWIDGET_H
 #define MARKDOWNPREVIEWWIDGET_H
 
-#include <QWidget>
 #include "markdownlib_private_export.h"
+#include <QWidget>
 class QWebEngineView;
 class MarkdownConverter;
 class QLabel;
@@ -17,7 +17,7 @@ class LIBKMAILMARKDOWNPRIVATE_TESTS_EXPORT MarkdownPreviewWidget : public QWidge
     Q_OBJECT
 public:
     explicit MarkdownPreviewWidget(QWidget *parent = nullptr);
-    ~MarkdownPreviewWidget();
+    ~MarkdownPreviewWidget() override;
     void setConverterSettings(bool enableEmbeddedLabel, bool enableExtraDefinitionLists);
 
 public Q_SLOTS:
