@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "externalcomposerplugineditor.h"
-#include "externalcomposerplugineditorinterface.h"
 #include "externalcomposerconfiguredialog.h"
+#include "externalcomposerplugineditorinterface.h"
 #include <KPluginFactory>
 
 K_PLUGIN_CLASS_WITH_JSON(ExternalComposerPluginEditor, "kmail_externalcomposereditorplugin.json")
@@ -22,7 +22,7 @@ ExternalComposerPluginEditor::~ExternalComposerPluginEditor()
 
 MessageComposer::PluginEditorInitInterface *ExternalComposerPluginEditor::createInterface(QObject *parent)
 {
-    auto *interface = new ExternalComposerPluginEditorInterface(parent);
+    auto interface = new ExternalComposerPluginEditorInterface(parent);
     return interface;
 }
 
