@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "insertemailplugineditorinterface.h"
 #include "selectmaildialog.h"
-#include <KPIMTextEdit/RichTextEditor>
-#include <KLocalizedString>
 #include <KActionCollection>
+#include <KLocalizedString>
+#include <KPIMTextEdit/RichTextEditor>
 #include <QAction>
 
 InsertEmailPluginEditorInterface::InsertEmailPluginEditorInterface(QObject *parent)
@@ -25,7 +25,7 @@ void InsertEmailPluginEditorInterface::createAction(KActionCollection *ac)
     QAction *action = new QAction(i18n("Insert Email..."), this);
     ac->addAction(QStringLiteral("insert_email"), action);
     connect(action, &QAction::triggered, this, &InsertEmailPluginEditorInterface::slotActivated);
-    MessageComposer::PluginActionType type(action, MessageComposer::PluginActionType::Edit);
+    MessageComposer::PluginActionType type(action, MessageComposer::PluginActionType::Insert);
     setActionType(type);
 }
 
