@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,10 @@
 #ifndef SHORTURLENGINEINTERFACE_H
 #define SHORTURLENGINEINTERFACE_H
 
-#include <QObject>
-#include <QNetworkReply>
-#include <QTextCursor>
 #include "shorturl_export.h"
+#include <QNetworkReply>
+#include <QObject>
+#include <QTextCursor>
 class QNetworkAccessManager;
 class ShortUrlEnginePlugin;
 class SHORTURL_EXPORT ShortUrlEngineInterface : public QObject
@@ -18,7 +18,7 @@ class SHORTURL_EXPORT ShortUrlEngineInterface : public QObject
     Q_OBJECT
 public:
     explicit ShortUrlEngineInterface(ShortUrlEnginePlugin *plugin, QObject *parent = nullptr);
-    ~ShortUrlEngineInterface();
+    ~ShortUrlEngineInterface() override;
 
     void setShortUrl(const QString &url);
     virtual void generateShortUrl() = 0;
