@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,15 +7,16 @@
 #include "automaticaddcontactstabwidget.h"
 #include <AkonadiCore/Collection>
 #include <AkonadiWidgets/CollectionComboBox>
+#include <KConfigGroup>
 #include <KContacts/Addressee>
 #include <KLocalizedString>
-#include <QCheckBox>
-#include <QVBoxLayout>
-#include <QLabel>
-#include <KConfigGroup>
 #include <KSharedConfig>
+#include <QCheckBox>
+#include <QLabel>
+#include <QVBoxLayout>
 
-namespace {
+namespace
+{
 QString configGroupName()
 {
     return QStringLiteral("Automatic Add Contacts %1");
@@ -24,14 +25,14 @@ QString configGroupName()
 AutomaticAddContactsTabWidget::AutomaticAddContactsTabWidget(QWidget *parent, QAbstractItemModel *model)
     : QWidget(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
     mEnabled = new QCheckBox(i18n("Automatic Add Contacts"), this);
     mEnabled->setObjectName(QStringLiteral("enabled"));
     connect(mEnabled, &QCheckBox::clicked, this, &AutomaticAddContactsTabWidget::configureChanged);
     mainLayout->addWidget(mEnabled);
 
-    auto *hlay = new QHBoxLayout;
+    auto hlay = new QHBoxLayout;
     hlay->setContentsMargins({});
     hlay->setObjectName(QStringLiteral("folderlayout"));
     mainLayout->addLayout(hlay);
