@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,10 +15,11 @@ class AutomaticAddContactsTabWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit AutomaticAddContactsTabWidgetTest(QObject *parent = nullptr);
-    ~AutomaticAddContactsTabWidgetTest();
+    ~AutomaticAddContactsTabWidgetTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldResetValue();
+
 private:
     AutomaticAddContactsTabWidget *createContactWidget();
     QStandardItemModel *mComboboxModel = nullptr;
