@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ class CheckBeforeSendPlugin : public MessageComposer::PluginEditorCheckBeforeSen
 {
     Q_OBJECT
 public:
-    explicit CheckBeforeSendPlugin(QObject *parent = nullptr, const QList<QVariant> & =
-    {
-    });
+    explicit CheckBeforeSendPlugin(QObject *parent = nullptr, const QList<QVariant> & = {});
     ~CheckBeforeSendPlugin() override;
 
     MessageComposer::PluginEditorCheckBeforeSendInterface *createInterface(QObject *parent) override;
