@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,9 +14,10 @@ class CheckAttachmentDialog : public QDialog
     Q_OBJECT
 public:
     explicit CheckAttachmentDialog(QWidget *parent = nullptr);
-    ~CheckAttachmentDialog();
+    ~CheckAttachmentDialog() override;
 
     void setEmails(const QStringList &emails);
+
 private:
     void writeConfig();
     void readConfig();
