@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class GrammarResultWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit GrammarResultWidgetTest(QObject *parent = nullptr);
-    ~GrammarResultWidgetTest() = default;
+    ~GrammarResultWidgetTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
