@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,9 @@
 #ifndef GRAMMALECTECONFIGWIDGET_H
 #define GRAMMALECTECONFIGWIDGET_H
 
-#include <QWidget>
-#include "libkmailgrammalecte_export.h"
 #include "grammalectegenerateconfigoptionjob.h"
+#include "libkmailgrammalecte_export.h"
+#include <QWidget>
 class QCheckBox;
 class KUrlRequester;
 class QStackedWidget;
@@ -19,9 +19,10 @@ class LIBKMAILGRAMMALECTE_EXPORT GrammalecteConfigWidget : public QWidget
     Q_OBJECT
 public:
     explicit GrammalecteConfigWidget(QWidget *parent = nullptr, bool disableMessageBox = false);
-    ~GrammalecteConfigWidget();
+    ~GrammalecteConfigWidget() override;
     void loadSettings();
     void saveSettings();
+
 private:
     Q_DISABLE_COPY(GrammalecteConfigWidget)
     void loadGrammarSettings();
