@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,7 +23,7 @@ void GrammalecteResultJob::start()
     if (canStart()) {
         mProcess = new QProcess(this);
 
-        auto *file = new QTemporaryFile(this);
+        auto file = new QTemporaryFile(this);
         file->open();
         file->setPermissions(QFile::ReadUser);
         file->write(mText.toUtf8());
@@ -38,8 +38,7 @@ void GrammalecteResultJob::start()
         args << QStringLiteral("-f") << file->fileName() << QStringLiteral("-j");
         mProcess->setArguments(args);
         connect(mProcess, qOverload<int, QProcess::ExitStatus>(&QProcess::finished), this, &GrammalecteResultJob::slotFinished);
-        connect(mProcess, qOverload<QProcess::ProcessError>(&QProcess::errorOccurred),
-                this, &GrammalecteResultJob::receivedError);
+        connect(mProcess, qOverload<QProcess::ProcessError>(&QProcess::errorOccurred), this, &GrammalecteResultJob::receivedError);
         connect(mProcess, &QProcess::readyReadStandardError, this, &GrammalecteResultJob::receivedStdErr);
         connect(mProcess, &QProcess::readyReadStandardOutput, this, &GrammalecteResultJob::receivedStandardOutput);
 
