@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef GRAMMARRESULTWIDGET_H
 #define GRAMMARRESULTWIDGET_H
 
-#include <QWidget>
 #include "grammarcommon_export.h"
 #include "grammarerror.h"
-namespace MessageComposer {
+#include <QWidget>
+namespace MessageComposer
+{
 class PluginGrammarAction;
 }
 class GrammarResultTextEdit;
@@ -20,7 +21,7 @@ class GRAMMARCOMMON_EXPORT GrammarResultWidget : public QWidget
     Q_OBJECT
 public:
     explicit GrammarResultWidget(QWidget *parent = nullptr);
-    ~GrammarResultWidget();
+    ~GrammarResultWidget() override;
     void setText(const QString &str);
     virtual void checkGrammar() = 0;
     void applyGrammarResult(const QVector<GrammarError> &infos);
