@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,9 @@
 #ifndef LANGUAGETOOLGETLISTOFLANGUAGEJOB_H
 #define LANGUAGETOOLGETLISTOFLANGUAGEJOB_H
 
+#include "libkmaillanguagetool_export.h"
 #include <QNetworkRequest>
 #include <QObject>
-#include "libkmaillanguagetool_export.h"
 class QNetworkAccessManager;
 class QNetworkReply;
 class LIBKMAILLANGUAGETOOL_EXPORT LanguageToolGetListOfLanguageJob : public QObject
@@ -17,7 +17,7 @@ class LIBKMAILLANGUAGETOOL_EXPORT LanguageToolGetListOfLanguageJob : public QObj
     Q_OBJECT
 public:
     explicit LanguageToolGetListOfLanguageJob(QObject *parent = nullptr);
-    ~LanguageToolGetListOfLanguageJob();
+    ~LanguageToolGetListOfLanguageJob() override;
 
     Q_REQUIRED_RESULT bool canStart() const;
     void start();
