@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,9 @@
 #ifndef LANGUAGETOOLMANAGER_H
 #define LANGUAGETOOLMANAGER_H
 
-#include <QObject>
-#include <QHash>
 #include "libkmaillanguagetool_export.h"
+#include <QHash>
+#include <QObject>
 class QColor;
 class QNetworkAccessManager;
 class LIBKMAILLANGUAGETOOL_EXPORT LanguageToolManager : public QObject
@@ -17,7 +17,7 @@ class LIBKMAILLANGUAGETOOL_EXPORT LanguageToolManager : public QObject
     Q_OBJECT
 public:
     explicit LanguageToolManager(QObject *parent = nullptr);
-    ~LanguageToolManager();
+    ~LanguageToolManager() override;
     static LanguageToolManager *self();
 
     QNetworkAccessManager *networkAccessManager() const;
@@ -41,6 +41,7 @@ public:
     static QString convertToLanguagePath(const QString &path);
 
     Q_REQUIRED_RESULT QColor grammarColorForError(const QString &error);
+
 private:
     Q_DISABLE_COPY(LanguageToolManager)
     QHash<QString, QColor> mGrammarColor;
