@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,10 +7,10 @@
 #include "mailmergewidgettest.h"
 #include "../widgets/mailmergewidget.h"
 #include <PimCommon/SimpleStringListEditor>
-#include <QTest>
 #include <QComboBox>
-#include <QStackedWidget>
 #include <QSignalSpy>
+#include <QStackedWidget>
+#include <QTest>
 using namespace MailMerge;
 Q_DECLARE_METATYPE(MailMerge::MailMergeWidget::SourceType)
 MailMergeWidgetTest::MailMergeWidgetTest()
@@ -32,8 +32,7 @@ void MailMergeWidgetTest::shouldHaveDefaultValueOnCreation()
 
     for (int i = 0; i < stackedwidget->count(); ++i) {
         const QString objectName = stackedwidget->widget(i)->objectName();
-        bool hasName = (objectName == QLatin1String("addressbookwidget")
-                        || objectName == QLatin1String("csvwidget"));
+        bool hasName = (objectName == QLatin1String("addressbookwidget") || objectName == QLatin1String("csvwidget"));
         QVERIFY(hasName);
     }
     PimCommon::SimpleStringListEditor *listEditor = mailmerge.findChild<PimCommon::SimpleStringListEditor *>(QStringLiteral("attachment-list"));
