@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -8,13 +8,14 @@
 #define MAILMERGEJOB_H
 
 #include <QObject>
-namespace MailMerge {
+namespace MailMerge
+{
 class MailMergeJob : public QObject
 {
     Q_OBJECT
 public:
     explicit MailMergeJob(QObject *parent = nullptr);
-    ~MailMergeJob();
+    ~MailMergeJob() override;
     void start();
 };
 }
