@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,11 +7,13 @@
 #define EMAILADDRESSSELECTIONLDAPDIALOG_H
 
 #include <Akonadi/Contact/AbstractEmailAddressSelectionDialog>
-namespace Akonadi {
+namespace Akonadi
+{
 class RecipientsPickerWidget;
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 class LdapSearchDialog;
 }
 
@@ -24,6 +26,7 @@ public:
 
     Akonadi::EmailAddressSelection::List selectedAddresses() const override;
     Akonadi::EmailAddressSelectionWidget *view() const override;
+
 private:
     void writeConfig();
     void readConfig();
