@@ -8,9 +8,9 @@
 #ifndef TESTOBJECTTREESOURCE_H
 #define TESTOBJECTTREESOURCE_H
 
-#include <MessageViewer/ObjectTreeEmptySource>
-#include <MessageViewer/CSSHelperBase>
 #include <MessageViewer/AttachmentStrategy>
+#include <MessageViewer/CSSHelperBase>
+#include <MessageViewer/ObjectTreeEmptySource>
 
 class TestObjectTreeSource : public MessageViewer::EmptySource
 {
@@ -76,7 +76,7 @@ public:
 
     QString createMessageHeader(KMime::Message *message) override
     {
-        Q_UNUSED(message);
+        Q_UNUSED(message)
         return QString();
     }
 
