@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
-    SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,8 +12,8 @@
 #include <KLocalizedString>
 
 #include <QCheckBox>
-#include <QLabel>
 #include <QDialogButtonBox>
+#include <QLabel>
 #include <QPushButton>
 #include <QVBoxLayout>
 
@@ -21,7 +21,7 @@ DelegateSelector::DelegateSelector(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Select delegate"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
     QLabel *label = new QLabel(i18n("Delegate:"), this);
     label->setObjectName(QStringLiteral("label"));
