@@ -11,13 +11,16 @@
 
 #include <QString>
 
-namespace MimeTreeParser {
-namespace Interface {
+namespace MimeTreeParser
+{
+namespace Interface
+{
 class BodyPart;
 }
 }
 
-namespace KMime {
+namespace KMime
+{
 class Content;
 }
 
@@ -28,12 +31,12 @@ public:
     enum ConfirmationType {
         UnknownType,
         ConfirmationRequest,
-        ConfirmationResponse
+        ConfirmationResponse,
     };
 
     explicit GnuPGWKSMessagePart(MimeTreeParser::Interface::BodyPart *part);
 
-    virtual ~GnuPGWKSMessagePart() = default;
+    ~GnuPGWKSMessagePart() override = default;
 
     ConfirmationType confirmationType() const;
     QString sender() const;
