@@ -1,24 +1,25 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dkimkeyrecordwidget.h"
-#include <MessageViewer/DKIMManagerKeyWidget>
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <MessageViewer/DKIMManagerKeyWidget>
 #include <QHBoxLayout>
 
-namespace {
-static const char myConfigGroupName[] = "DKIMKeyRecordWidget";
+namespace
+{
+static const char myDKIMKeyRecordWidgetGroupName[] = "DKIMKeyRecordWidget";
 }
 
 DKIMKeyRecordWidget::DKIMKeyRecordWidget(QWidget *parent)
     : QWidget(parent)
     , mManagerKeyWidget(new MessageViewer::DKIMManagerKeyWidget(this))
 {
-    auto *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
 
     mManagerKeyWidget->setObjectName(QStringLiteral("mManagerKeyWidget"));
@@ -33,13 +34,13 @@ DKIMKeyRecordWidget::~DKIMKeyRecordWidget()
 
 void DKIMKeyRecordWidget::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), myConfigGroupName);
+    KConfigGroup group(KSharedConfig::openConfig(), myDKIMKeyRecordWidgetGroupName);
     mManagerKeyWidget->restoreHeaders(group.readEntry("Header", QByteArray()));
 }
 
 void DKIMKeyRecordWidget::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), myConfigGroupName);
+    KConfigGroup group(KSharedConfig::openConfig(), myDKIMKeyRecordWidgetGroupName);
     group.writeEntry("Header", mManagerKeyWidget->saveHeaders());
     group.sync();
 }
