@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,12 +11,10 @@
 FolderConfigureModifyCollectionJob::FolderConfigureModifyCollectionJob(QObject *parent)
     : QObject(parent)
 {
-
 }
 
 FolderConfigureModifyCollectionJob::~FolderConfigureModifyCollectionJob()
 {
-
 }
 
 void FolderConfigureModifyCollectionJob::setCollection(const Akonadi::Collection &col)
@@ -26,7 +24,7 @@ void FolderConfigureModifyCollectionJob::setCollection(const Akonadi::Collection
 
 void FolderConfigureModifyCollectionJob::start()
 {
-    auto *job = new Akonadi::CollectionModifyJob(mCollection, this);
+    auto job = new Akonadi::CollectionModifyJob(mCollection, this);
     connect(job, &Akonadi::CollectionModifyJob::result, this, &FolderConfigureModifyCollectionJob::slotCollectionModified);
 }
 
