@@ -1,20 +1,20 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "grantleeheaderstyleplugintest.h"
-#include "utils.h"
-#include "../grantleeheaderstyleplugin/grantleeheaderstyleplugin.h"
 #include "../grantleeheaderstyleplugin/grantleeheaderstyleinterface.h"
+#include "../grantleeheaderstyleplugin/grantleeheaderstyleplugin.h"
+#include "utils.h"
 
 #include <GrantleeTheme/GrantleeThemeManager>
 #include <MessageViewer/HeaderStyle>
 #include <MimeTreeParser/NodeHelper>
 
-#include <QTest>
 #include <QStandardPaths>
+#include <QTest>
 
 #include <KActionCollection>
 #include <KActionMenu>
@@ -74,12 +74,12 @@ void GrantleeHeaderStylePluginTest::shouldHaveDefaultValue()
 void GrantleeHeaderStylePluginTest::shouldCreateInterface()
 {
     MessageViewer::GrantleeHeaderStylePlugin plugin;
-    auto *menu = new KActionMenu(this);
-    auto *act = new QActionGroup(this);
+    auto menu = new KActionMenu(this);
+    auto act = new QActionGroup(this);
 
     MessageViewer::HeaderStyleInterface *interface = plugin.createView(menu, act, new KActionCollection(this));
     QVERIFY(interface);
-    //QVERIFY(!interface->action().isEmpty());
+    // QVERIFY(!interface->action().isEmpty());
 }
 
 void GrantleeHeaderStylePluginTest::testThemeActivation_data()
@@ -99,10 +99,11 @@ void GrantleeHeaderStylePluginTest::testThemeActivation()
     QFETCH(QString, themeName);
 
     MessageViewer::GrantleeHeaderStylePlugin plugin;
-    auto *menu = new KActionMenu(this);
-    auto *act = new QActionGroup(this);
+    auto menu = new KActionMenu(this);
+    auto act = new QActionGroup(this);
 
-    MessageViewer::GrantleeHeaderStyleInterface *interface = static_cast<MessageViewer::GrantleeHeaderStyleInterface *>(plugin.createView(menu, act, new KActionCollection(this)));
+    MessageViewer::GrantleeHeaderStyleInterface *interface =
+        static_cast<MessageViewer::GrantleeHeaderStyleInterface *>(plugin.createView(menu, act, new KActionCollection(this)));
     QVERIFY(interface);
 
     QVERIFY(interface->mThemeManager->themes().contains(themeName));
@@ -133,7 +134,7 @@ void GrantleeHeaderStylePluginTest::testThemeRender_data()
             if (!themeDir.exists(file + QStringLiteral(".html"))) {
                 continue;
             }
-            QTest::newRow(QString(themeDir.dirName() + QStringLiteral("-") + file).toLatin1().constData()) << themeDir.dirName() <<  file;
+            QTest::newRow(QString(themeDir.dirName() + QStringLiteral("-") + file).toLatin1().constData()) << themeDir.dirName() << file;
         }
     }
 }
@@ -148,10 +149,11 @@ void GrantleeHeaderStylePluginTest::testThemeRender()
     auto *style = plugin.headerStyle();
     MimeTreeParser::NodeHelper nodeHelper;
     style->setNodeHelper(&nodeHelper);
-    auto *menu = new KActionMenu(this);
-    auto *act = new QActionGroup(this);
+    auto menu = new KActionMenu(this);
+    auto act = new QActionGroup(this);
 
-    MessageViewer::GrantleeHeaderStyleInterface *interface = static_cast<MessageViewer::GrantleeHeaderStyleInterface *>(plugin.createView(menu, act, new KActionCollection(this)));
+    MessageViewer::GrantleeHeaderStyleInterface *interface =
+        static_cast<MessageViewer::GrantleeHeaderStyleInterface *>(plugin.createView(menu, act, new KActionCollection(this)));
     QVERIFY(interface);
 
     QVERIFY(interface->mThemeManager->themes().contains(themeName));
