@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,17 +15,17 @@
 #include <QVBoxLayout>
 
 #include <KActionCollection>
-#include <QTextEdit>
 #include <KActionMenu>
 #include <MessageViewer/HeaderStrategy>
 #include <MessageViewer/HeaderStyle>
 #include <MessageViewer/HeaderStylePlugin>
+#include <QTextEdit>
 
 HeaderStyleMenuTest::HeaderStyleMenuTest(QWidget *parent)
     : QWidget(parent)
 {
-    auto *menu = new QMenuBar(this);
-    auto *hbox = new QVBoxLayout(this);
+    auto menu = new QMenuBar(this);
+    auto hbox = new QVBoxLayout(this);
     hbox->addWidget(menu);
     MessageViewer::HeaderStyleMenuManager *manager = new MessageViewer::HeaderStyleMenuManager(new KActionCollection(this), this);
     menu->addAction(manager->menu());
@@ -42,8 +42,8 @@ HeaderStyleMenuTest::~HeaderStyleMenuTest()
 
 void HeaderStyleMenuTest::styleChanged(MessageViewer::HeaderStylePlugin *plugin)
 {
-    mTextEdit->append(QStringLiteral("strategy: %1, headerstyle: %2").arg(QLatin1String(plugin->headerStrategy()->name()))
-                      .arg(QLatin1String(plugin->headerStyle()->name())));
+    mTextEdit->append(
+        QStringLiteral("strategy: %1, headerstyle: %2").arg(QLatin1String(plugin->headerStrategy()->name())).arg(QLatin1String(plugin->headerStyle()->name())));
 }
 
 int main(int argc, char **argv)
@@ -55,7 +55,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    auto *w = new HeaderStyleMenuTest();
+    auto w = new HeaderStyleMenuTest();
     w->resize(800, 200);
     w->show();
     app.exec();
