@@ -5,21 +5,22 @@
 */
 
 #include "noteedittest.h"
-#include "globalsettings_messageviewer.h"
 #include "../createnoteplugin/noteedit.h"
+#include "globalsettings_messageviewer.h"
 #include <AkonadiCore/Collection>
-#include <AkonadiWidgets/CollectionComboBox>
 #include <AkonadiCore/EntityTreeModel>
+#include <AkonadiWidgets/CollectionComboBox>
 #include <KMime/KMimeMessage>
 
 #include <QLineEdit>
 #include <QPushButton>
 #include <QShortcut>
-#include <QStandardItemModel>
 #include <QSignalSpy>
+#include <QStandardItemModel>
 #include <QTest>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 extern MESSAGEVIEWER_EXPORT QAbstractItemModel *_k_noteEditStubModel;
 }
 
@@ -29,7 +30,7 @@ NoteEditTest::NoteEditTest()
     qRegisterMetaType<KMime::Message::Ptr>();
     QStandardPaths::setTestModeEnabled(true);
 
-    auto *model = new QStandardItemModel;
+    auto model = new QStandardItemModel;
     for (int id = 42; id < 51; ++id) {
         Akonadi::Collection collection(id);
         collection.setRights(Akonadi::Collection::AllRights);
@@ -37,10 +38,8 @@ NoteEditTest::NoteEditTest()
         collection.setContentMimeTypes(QStringList() << Akonadi::NoteUtils::noteMimeType());
 
         QStandardItem *item = new QStandardItem(collection.name());
-        item->setData(QVariant::fromValue(collection),
-                      Akonadi::EntityTreeModel::CollectionRole);
-        item->setData(QVariant::fromValue(collection.id()),
-                      Akonadi::EntityTreeModel::CollectionIdRole);
+        item->setData(QVariant::fromValue(collection), Akonadi::EntityTreeModel::CollectionRole);
+        item->setData(QVariant::fromValue(collection.id()), Akonadi::EntityTreeModel::CollectionIdRole);
 
         model->appendRow(item);
     }
@@ -335,7 +334,7 @@ void NoteEditTest::shouldSaveCollectionSettingsWhenCloseWidget()
 
 void NoteEditTest::shouldSaveCollectionSettingsWhenDeleteWidget()
 {
-    auto *edit = new MessageViewer::NoteEdit;
+    auto edit = new MessageViewer::NoteEdit;
     auto *akonadicombobox = edit->findChild<Akonadi::CollectionComboBox *>(QStringLiteral("akonadicombobox"));
     akonadicombobox->setCurrentIndex(4);
     const Akonadi::Collection::Id id = akonadicombobox->currentCollection().id();
