@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,19 +7,20 @@
 #include "viewerplugincreateeventtest.h"
 #include "../createeventplugin/viewerplugincreateevent.h"
 #include <KActionCollection>
-#include <QTest>
-#include <QStandardItemModel>
 #include <MessageViewer/ViewerPluginInterface>
 #include <QHBoxLayout>
+#include <QStandardItemModel>
+#include <QTest>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 extern MESSAGEVIEWER_EXPORT QAbstractItemModel *_k_eventEditStubModel;
 }
 
 ViewerPluginCreateeventTest::ViewerPluginCreateeventTest(QObject *parent)
     : QObject(parent)
 {
-    auto *model = new QStandardItemModel;
+    auto model = new QStandardItemModel;
     MessageViewer::_k_eventEditStubModel = model;
 }
 
