@@ -1,35 +1,36 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "eventedit.h"
 #include "createeventplugin_debug.h"
-#include "globalsettings_messageviewer.h"
 #include "eventdatetimewidget.h"
+#include "globalsettings_messageviewer.h"
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
 #include <KLocalizedString>
-#include <QLineEdit>
-#include <QIcon>
 #include <QDateTime>
+#include <QIcon>
+#include <QLineEdit>
 
-#include <QHBoxLayout>
 #include <QEvent>
+#include <QHBoxLayout>
 #include <QKeyEvent>
 #include <QLabel>
 
 #include <AkonadiWidgets/CollectionComboBox>
 #include <QPushButton>
 
-#include <IncidenceEditor/IncidenceDialogFactory>
 #include <IncidenceEditor/IncidenceDialog>
+#include <IncidenceEditor/IncidenceDialogFactory>
 #include <KGuiItem>
 #include <KStandardGuiItem>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 QAbstractItemModel *_k_eventEditStubModel = nullptr;
 }
 
@@ -38,11 +39,11 @@ using namespace MessageViewer;
 EventEdit::EventEdit(QWidget *parent)
     : QWidget(parent)
 {
-    auto *vbox = new QVBoxLayout(this);
+    auto vbox = new QVBoxLayout(this);
     vbox->setContentsMargins(5, 5, 5, 5);
     vbox->setSpacing(2);
 
-    auto *hbox = new QHBoxLayout;
+    auto hbox = new QHBoxLayout;
     hbox->setContentsMargins({});
     hbox->setSpacing(2);
     vbox->addLayout(hbox);
@@ -103,8 +104,7 @@ EventEdit::EventEdit(QWidget *parent)
 #ifndef QT_NO_ACCESSIBILITY
     mEndDateTimeEdit->setAccessibleDescription(i18n("Select end time for event."));
 #endif
-    connect(mEndDateTimeEdit, &EventDateTimeWidget::dateTimeChanged,
-            this, &EventEdit::slotEndDateTimeChanged);
+    connect(mEndDateTimeEdit, &EventDateTimeWidget::dateTimeChanged, this, &EventEdit::slotEndDateTimeChanged);
 
     hbox->addWidget(mEndDateTimeEdit);
 
@@ -126,7 +126,7 @@ EventEdit::EventEdit(QWidget *parent)
     connect(mSaveButton, &QPushButton::clicked, this, &EventEdit::slotReturnPressed);
     hbox->addWidget(mSaveButton);
 
-    mOpenEditorButton = new QPushButton(i18n("Open &editor..."), this);
+    mOpenEditorButton = new QPushButton(i18n("Open &Editor..."), this);
 #ifndef QT_NO_ACCESSIBILITY
     mOpenEditorButton->setAccessibleDescription(i18n("Open event editor, where more details can be changed."));
 #endif
@@ -135,7 +135,7 @@ EventEdit::EventEdit(QWidget *parent)
     connect(mOpenEditorButton, &QPushButton::clicked, this, &EventEdit::slotOpenEditor);
     hbox->addWidget(mOpenEditorButton);
 
-    auto *btn = new QPushButton(this);
+    auto btn = new QPushButton(this);
     KGuiItem::assign(btn, KStandardGuiItem::cancel());
     btn->setObjectName(QStringLiteral("close-button"));
 #ifndef QT_NO_ACCESSIBILITY
@@ -278,14 +278,12 @@ bool EventEdit::eventFilter(QObject *object, QEvent *e)
     // With a shortcut override we can catch this before it gets to kactions.
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
     if (shortCutOverride) {
-        auto *kev = static_cast<QKeyEvent * >(e);
+        auto kev = static_cast<QKeyEvent *>(e);
         if (kev->key() == Qt::Key_Escape) {
             e->accept();
             slotCloseWidget();
             return true;
-        } else if (kev->key() == Qt::Key_Enter
-                   || kev->key() == Qt::Key_Return
-                   || kev->key() == Qt::Key_Space) {
+        } else if (kev->key() == Qt::Key_Enter || kev->key() == Qt::Key_Return || kev->key() == Qt::Key_Space) {
             e->accept();
             if (object == mCollectionCombobox) {
                 mCollectionCombobox->showPopup();
