@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,8 @@
 #define VIEWERPLUGINCREATEEVENT_H
 #include <MessageViewer/ViewerPlugin>
 #include <QVariant>
-namespace MessageViewer {
+namespace MessageViewer
+{
 class ViewerPluginCreateevent : public MessageViewer::ViewerPlugin
 {
     Q_OBJECT
