@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef VIEWERPLUGINCREATEEVENTINTERFACE_H
 #define VIEWERPLUGINCREATEEVENTINTERFACE_H
 
-#include <MessageViewer/ViewerPluginInterface>
 #include <KCalendarCore/Event>
+#include <MessageViewer/ViewerPluginInterface>
 class KActionCollection;
-namespace MessageViewer {
+namespace MessageViewer
+{
 class EventEdit;
 class ViewerPluginCreateEventInterface : public ViewerPluginInterface
 {
