@@ -1,21 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "viewerplugincreatenoteinterface.h"
-#include "noteedit.h"
 #include "createnotejob.h"
 #include "createnoteplugin_debug.h"
-#include <KLocalizedString>
+#include "noteedit.h"
 #include <KActionCollection>
+#include <KLocalizedString>
 
-#include <QLayout>
-#include <QIcon>
-#include <QAction>
 #include <ItemFetchJob>
 #include <ItemFetchScope>
+#include <QAction>
+#include <QIcon>
+#include <QLayout>
 
 using namespace MessageViewer;
 
@@ -31,8 +31,8 @@ ViewerPluginCreatenoteInterface::~ViewerPluginCreatenoteInterface()
 
 void ViewerPluginCreatenoteInterface::setText(const QString &text)
 {
-    Q_UNUSED(text);
-    //Nothing
+    Q_UNUSED(text)
+    // Nothing
 }
 
 QList<QAction *> ViewerPluginCreatenoteInterface::actions() const
@@ -91,7 +91,7 @@ void ViewerPluginCreatenoteInterface::slotNoteItemFetched(KJob *job)
         qCDebug(CREATENOTEPLUGIN_LOG) << "There is not valid note:" << job->errorString();
         showCreateNewNoteWidget();
     } else {
-        auto *fetch = qobject_cast<Akonadi::ItemFetchJob *>(job);
+        auto fetch = qobject_cast<Akonadi::ItemFetchJob *>(job);
         Q_ASSERT(fetch);
         if (fetch->items().isEmpty() || !fetch->items().constFirst().hasPayload<KMime::Message::Ptr>()) {
             showCreateNewNoteWidget();
@@ -144,14 +144,14 @@ void ViewerPluginCreatenoteInterface::createAction(KActionCollection *ac)
 
 void ViewerPluginCreatenoteInterface::slotCreateNote(const KMime::Message::Ptr &notePtr, const Akonadi::Collection &collection)
 {
-    auto *createJob = new CreateNoteJob(notePtr, collection, mMessageItem, this);
+    auto createJob = new CreateNoteJob(notePtr, collection, mMessageItem, this);
     createJob->start();
 }
 
 NoteEdit *ViewerPluginCreatenoteInterface::widget()
 {
     if (!mNoteEdit) {
-        auto *parentWidget = static_cast<QWidget *>(parent());
+        auto parentWidget = static_cast<QWidget *>(parent());
         mNoteEdit = new NoteEdit(parentWidget);
         connect(mNoteEdit, &NoteEdit::createNote, this, &ViewerPluginCreatenoteInterface::slotCreateNote);
         mNoteEdit->setObjectName(QStringLiteral("noteedit"));
