@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   This file originates from QupZilla - WebKit based browser
   SPDX-FileCopyrightText: 2013-2014 David Rosca <nowrep@gmail.com>
@@ -11,13 +11,14 @@
 #ifndef ADBLOCKRULE_H
 #define ADBLOCKRULE_H
 
+#include "adblockregexp.h"
 #include <QStringList>
 #include <QStringMatcher>
-#include "adblockregexp.h"
 class QUrl;
 class QWebEngineUrlRequestInfo;
 
-namespace AdBlock {
+namespace AdBlock
+{
 class AdBlockSubscription;
 
 class AdBlockRule
@@ -78,7 +79,7 @@ private:
         RegExpMatchRule = 2,
         StringEndsMatchRule = 3,
         StringContainsMatchRule = 4,
-        Invalid = 5
+        Invalid = 5,
     };
 
     enum RuleOption {
@@ -94,7 +95,7 @@ private:
 
         // Exception only options
         DocumentOption = 1024,
-        ElementHideOption = 2048
+        ElementHideOption = 2048,
     };
 
     Q_DECLARE_FLAGS(RuleOptions, RuleOption)
