@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   This file originates from QupZilla - WebKit based browser
   SPDX-FileCopyrightText: 2013-2014 David Rosca <nowrep@gmail.com>
@@ -11,8 +11,8 @@
 #ifndef ADBLOCKSUBSCRIPTION_H
 #define ADBLOCKSUBSCRIPTION_H
 
-#include <QVector>
 #include <QUrl>
+#include <QVector>
 
 #include "adblockrule.h"
 #include "adblocksearchtree.h"
@@ -20,13 +20,14 @@
 class QNetworkAccessManager;
 class QUrl;
 class QNetworkReply;
-namespace AdBlock {
+namespace AdBlock
+{
 class AdBlockSubscription : public QObject
 {
     Q_OBJECT
 public:
     explicit AdBlockSubscription(const QString &title, QObject *parent = nullptr);
-    ~AdBlockSubscription();
+    ~AdBlockSubscription() override;
 
     Q_REQUIRED_RESULT QString title() const;
 
@@ -100,6 +101,7 @@ public:
     int addRule(AdBlockRule *rule) override;
     bool removeRule(int offset) override;
     const AdBlockRule *replaceRule(AdBlockRule *rule, int offset) override;
+
 private:
     QByteArray readAllFileByteContents(const QString &filename);
 };
