@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include <QDialog>
-#include <QApplication>
-#include <QVBoxLayout>
-#include <QPushButton>
-#include <QCommandLineParser>
-#include <QDialogButtonBox>
-#include <QStandardPaths>
 #include "../widgets/adblocksettingwidget.h"
+#include <QApplication>
+#include <QCommandLineParser>
+#include <QDialog>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QStandardPaths>
+#include <QVBoxLayout>
 
 int main(int argc, char **argv)
 {
@@ -22,9 +22,9 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    auto *w = new AdBlock::AdBlockSettingWidget;
+    auto w = new AdBlock::AdBlockSettingWidget;
     QDialog dlg;
-    auto *layout = new QVBoxLayout;
+    auto layout = new QVBoxLayout;
     dlg.setLayout(layout);
     layout->addWidget(w);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
