@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef ADBLOCKPLUGINURLINTERCEPTORCONFIGUREWIDGET_H
 #define ADBLOCKPLUGINURLINTERCEPTORCONFIGUREWIDGET_H
 
-#include <WebEngineViewer/NetworkPluginUrlInterceptorConfigureWidget>
 #include "adblocklib_export.h"
+#include <WebEngineViewer/NetworkPluginUrlInterceptorConfigureWidget>
 
-namespace AdBlock {
+namespace AdBlock
+{
 class AdBlockSettingWidget;
 class ADBLOCKLIB_EXPORT AdblockPluginUrlInterceptorConfigureWidget : public WebEngineViewer::NetworkPluginUrlInterceptorConfigureWidget
 {
