@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef SELECTIMAPCREATEFOLDERJOB_H
 #define SELECTIMAPCREATEFOLDERJOB_H
 
-#include <QObject>
 #include <KSieveUi/SieveImapAccountSettings>
+#include <QObject>
 class KJob;
-namespace KIMAP {
+namespace KIMAP
+{
 class Session;
 }
 class SelectImapCreateFolderJob : public QObject
@@ -18,7 +19,7 @@ class SelectImapCreateFolderJob : public QObject
     Q_OBJECT
 public:
     explicit SelectImapCreateFolderJob(QObject *parent = nullptr);
-    ~SelectImapCreateFolderJob();
+    ~SelectImapCreateFolderJob() override;
     void start();
     void setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &account);
 
