@@ -1,21 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
    based on subscriptiondialog from kdepim-runtime
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "selectimapfolderwidget.h"
-#include "selectimaploadfoldersjob.h"
-#include "selectimapfoldertreeview.h"
-#include "selectimapfoldermodel.h"
 #include "imapfoldercompletionplugin_debug.h"
+#include "selectimapfoldermodel.h"
+#include "selectimapfoldertreeview.h"
+#include "selectimaploadfoldersjob.h"
 #include <KMessageBox>
-#include <QStandardItemModel>
 #include <QHeaderView>
-#include <QLineEdit>
 #include <QInputDialog>
+#include <QLineEdit>
 #include <QSortFilterProxyModel>
+#include <QStandardItemModel>
 #include <QVBoxLayout>
 
 #include <KLocalizedString>
@@ -28,11 +28,11 @@ SelectImapFolderWidget::SelectImapFolderWidget(const KSieveUi::SieveImapAccountS
     bool modelIsInitialized = false;
     mModel = SelectImapFolderModel::self()->folderModel(mAccount, modelIsInitialized);
     connect(SelectImapFolderModel::self(), &SelectImapFolderModel::modelLoaded, this, &SelectImapFolderWidget::slotModelLoaded);
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
     mainLayout->setContentsMargins({});
 
-    auto *topLayout = new QHBoxLayout;
+    auto topLayout = new QHBoxLayout;
     topLayout->setContentsMargins({});
     mainLayout->addLayout(topLayout);
     mSearchLineEdit = new QLineEdit(this);
@@ -41,7 +41,7 @@ SelectImapFolderWidget::SelectImapFolderWidget(const KSieveUi::SieveImapAccountS
     mSearchLineEdit->setPlaceholderText(i18n("Search..."));
     topLayout->addWidget(mSearchLineEdit);
 
-    auto *refreshImap = new QToolButton(this);
+    auto refreshImap = new QToolButton(this);
     refreshImap->setObjectName(QStringLiteral("refreshimap"));
     refreshImap->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
     refreshImap->setToolTip(i18n("Refresh IMAP Folder List"));
@@ -116,7 +116,7 @@ void SelectImapFolderWidget::createFolder()
                 KMessageBox::error(this, i18n("Slashes are not allowed in folder names."), i18n("Create Folder"));
                 return;
             }
-            //TODO more check for folder name ?
+            // TODO more check for folder name ?
             SelectImapFolderModel::self()->createNewFolder(mAccount, currentPath + QLatin1Char('/') + name);
         } else {
             KMessageBox::error(this, i18n("Empty folder name is not supported."), i18n("Create Folder"));
@@ -126,7 +126,7 @@ void SelectImapFolderWidget::createFolder()
 
 void SelectImapFolderWidget::slotCurrentChanged(const QModelIndex &current, const QModelIndex &previous)
 {
-    Q_UNUSED(previous);
+    Q_UNUSED(previous)
     Q_EMIT folderIsSelected(current.isValid());
 }
 
