@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef SELECTIMAPFOLDERWIDGET_H
 #define SELECTIMAPFOLDERWIDGET_H
 
-#include <QWidget>
 #include <QTreeView>
+#include <QWidget>
 
 #include <KSieveUi/SieveImapAccountSettings>
 
@@ -22,9 +22,9 @@ class SelectImapFolderWidget : public QWidget
     Q_OBJECT
 public:
     explicit SelectImapFolderWidget(const KSieveUi::SieveImapAccountSettings &account, QWidget *parent = nullptr);
-    ~SelectImapFolderWidget();
+    ~SelectImapFolderWidget() override;
 
-    QString selectedFolderName() const;
+    Q_REQUIRED_RESULT QString selectedFolderName() const;
     void createFolder();
 
 Q_SIGNALS:
