@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,8 @@
 #define SELECTIMAPLINEEDIT_H
 
 #include <QLineEdit>
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveImapAccountSettings;
 }
 
@@ -17,9 +18,10 @@ class SelectImapLineEdit : public QLineEdit
     Q_OBJECT
 public:
     explicit SelectImapLineEdit(QWidget *parent = nullptr);
-    ~SelectImapLineEdit();
+    ~SelectImapLineEdit() override;
 
     void setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &account);
+
 private:
     QCompleter *mCompleter = nullptr;
 };
