@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "selectimapwidget.h"
+#include "imapfoldercompletionplugin_debug.h"
 #include "selectimapfolderdialog.h"
 #include "selectimaplineedit.h"
-#include "imapfoldercompletionplugin_debug.h"
 #include <KLocalizedString>
-#include <QToolButton>
 #include <QHBoxLayout>
+#include <QToolButton>
 
 #include <KPluginFactory>
 K_PLUGIN_CLASS_WITH_JSON(SelectImapWidget, "imapfoldercompletion.json")
@@ -18,7 +18,7 @@ K_PLUGIN_CLASS_WITH_JSON(SelectImapWidget, "imapfoldercompletion.json")
 SelectImapWidget::SelectImapWidget(QWidget *parent, const QList<QVariant> &)
     : KSieveUi::AbstractMoveImapFolderWidget(parent)
 {
-    auto *layout = new QHBoxLayout(this);
+    auto layout = new QHBoxLayout(this);
     layout->setObjectName(QStringLiteral("mainlayout"));
     layout->setContentsMargins({});
     mLineEdit = new SelectImapLineEdit(this);
